/* Exports an object that defines
 *  all of the configuration needed by the projects'
 *  depended-on grunt tasks.
 *
 * You can find the parent object in: node_modules/lineman/config/application.coffee
 */

module.exports = require(process.env['LINEMAN_MAIN']).config.extend('application', {

  // configure lineman to load additional angular related npm tasks
  loadNpmTasks: [
    // "grunt-angular-templates",
    "grunt-concat-sourcemap",
    "grunt-ngmin"
  ],

  // we don't use the lineman default concat, handlebars, and jst tasks by default
  removeTasks: {
    common: ["concat", "handlebars", "jst", "images:dev", "webfonts:dev", "pages:dev"],
    dev: ["server"],
    dist: ["images:dist", "webfonts:dist", "pages:dist"]
  },

  // task override configuration
  prependTasks: {
    dist: ["ngmin"],         // ngmin should run in dist only
    // common: ["ngtemplates"], // ngtemplates runs in dist and dev
    dist: ["concat:jsdist", "concat:lessdist"]
  },

  // swaps concat_sourcemap in place of vanilla concat
  appendTasks: {
    common: ["concat_sourcemap:js", "concat_sourcemap:spec", "concat_sourcemap:spechelpers", "concat_sourcemap:vendor"]
  },

  // configuration for grunt-angular-templates
  // ngtemplates: {
  //   app: { // "app" matches the name of the angular module defined in app.js
  //     options: {
  //       base: "app/templates"
  //     },
  //     src: "app/templates/**/*.html",
  //     // puts angular templates in a different spot than lineman looks for other templates in order not to conflict with the watch process
  //     dest: "generated/angular/template-cache.js"
  //   }
  // },

  // configuration for grunt-ngmin, this happens _after_ concat once, which is the ngmin ideal :)
  ngmin: {
    js: {
      src: "<%= files.js.concatenated %>",
      dest: "<%= files.js.concatenated %>"
    }
  },

  // generates a sourcemap for js, specs, and css with inlined sources
  // grunt-angular-templates expects that a module already be defined to inject into
  // this configuration orders the template inclusion _after_ the app level module
  concat_sourcemap: {
    options: {
      sourcesContent: true
    },
    js: {
      src: ["<%= files.js.app %>", "<%= files.coffee.generated %>"],
      dest: "<%= files.js.concatenated %>"
    },
    spec: {
      src: ["<%= files.js.spec %>", "<%= files.coffee.generatedSpec %>"],
      dest: "<%= files.js.concatenatedSpec %>"
    },
    spechelpers: {
      src: ["<%= files.js.specHelpers %>", "<%= files.coffee.generatedSpecHelpers %>"],
      dest: "<%= files.js.spechelpers.js %>"
    },
    // css: {
    //   src: ["<%= files.less.generatedVendor %>", "<%= files.sass.generatedVendor %>", "<%= files.css.vendor %>", "<%= files.less.generatedApp %>", "<%= files.sass.generatedApp %>", "<%= files.css.app %>"],
    //   dest: "<%= files.css.concatenated %>"
    // },
    vendor: {
      src: ["<%= files.js.vendor %>"],
      dest: "<%= files.js.vendorCurrent %>"
    }  
  },

  // Only for dist, we don't need source map
  concat: {
    jsdist: {
      src: ["<%= files.js.app %>", "<%= files.coffee.generated %>"],
      dest: "<%= files.js.uncompressed %>"
    },
    lessdist: {
      src: ["<%= files.less.app %>"],
      dest: "<%= files.less.dist %>"
    }
  },

  uglify: {
    js: {
      files: {
        "<%= files.js.minified %>": "<%= files.js.uncompressed %>"
      }
    }
  },

  // configures grunt-watch-nospawn to listen for changes to
  // and recompile angular templates, also swaps lineman default
  // watch target concat with concat_sourcemap
  watch: {
    // ngtemplates: {
    //   files: "app/templates/**/*.html",
    //   tasks: ["ngtemplates", "concat_sourcemap:js"]
    // },
    js: {
      files: ["<%= files.js.vendor %>", "<%= files.js.app %>"],
      tasks: ["concat_sourcemap:js"]
    },
    coffee: {
      files: "<%= files.coffee.app %>",
      tasks: ["coffee", "concat_sourcemap:js"]
    },
    jsSpecs: {
      files: ["<%= files.js.specHelpers %>", "<%= files.js.spec %>"],
      tasks: ["concat_sourcemap:spec"]
    },
    coffeeSpecs: {
      files: ["<%= files.coffee.specHelpers %>", "<%= files.coffee.spec %>"],
      tasks: ["coffee", "concat_sourcemap:spec"]
    },
    // css: {
    //   files: ["<%= files.css.vendor %>", "<%= files.css.app %>"],
    //   tasks: ["concat_sourcemap:css"]
    // },
    less: {
      files: ["<%= files.less.vendor %>", "<%= files.less.app %>"],
      tasks: ["less", "concat_sourcemap:css"]
    },
    sass: {
      files: ["<%= files.sass.vendor %>", "<%= files.sass.app %>"],
      tasks: ["sass", "concat_sourcemap:css"]
    }
  }

});
